Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-pages.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'internal/source/disk/disk.go')
-rw-r--r--internal/source/disk/disk.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/source/disk/disk.go b/internal/source/disk/disk.go
index 2283cad4..a3ae8901 100644
--- a/internal/source/disk/disk.go
+++ b/internal/source/disk/disk.go
@@ -52,9 +52,9 @@ func (d *Disk) IsReady() bool {
return d.dm != nil
}
// Start starts the domain source, in this case it is reading domains from
// groups on disk concurrently.
-func (d *Disk) Start(rootDomain string) {
+func (d *Disk) Read(rootDomain string) {
go Watch(rootDomain, d.updateDomains, time.Second)
}
@@ -52,9 +52,9 @@ func (d *Disk) IsReady() bool {
return d.dm != nil
}
-// Start starts the domain source, in this case it is reading domains from
+// Read starts the domain source, in this case it is reading domains from
// groups on disk concurrently.